@@ -55,7 +55,7 @@ def test_transform(benchmark):
     pc = PointCloud([Point() for _ in range(10000)])
     tf = Transform(Point(1), Rotation(0, 0, np.pi))
     pc = benchmark(pc.transform, tf)
-    assert pytest.approx(pc[0].x) == -1
+    assert pytest.approx(pc[0].x) == 1
 
 
 def test_get_point_cloud():
