@@ -30,6 +30,7 @@ class Event(Enum):
 class MouseEvent:
     position: Tuple[int, int]
     last_position: Tuple[int, int]
+    world_position: Point
 
 
 @dataclass
@@ -97,7 +98,7 @@ class Interactor:
         else:
 
             def _callback(mouse, _):
-                callback(MouseEvent(mouse.GetEventPosition(), mouse.GetLastEventPosition()))
+                callback(MouseEvent(mouse.GetEventPosition(), mouse.GetLastEventPosition(), self.get_cursor_in_world()))
 
         self._interactor.AddObserver(event.value, _callback, 1.0)
 
@@ -211,6 +212,6 @@ class Interactor:
         cam_position = self.viewer.camera.get_position()
         cam_to_focal_proj = focal_plane_projection - cam_position
         r, theta, phi = cartesian_to_spherical(cam_to_focal_proj.x, cam_to_focal_proj.y, cam_to_focal_proj.z)
-        r *= (world_z - cam_position.z) / cam_to_focal_proj.z
+        r *= (world_z - cam_position.z) / (cam_to_focal_proj.z + np.finfo(float).eps)
         cam_to_focal_proj = Point(*spherical_to_cartesian(r, theta, phi))
         return cam_position + cam_to_focal_proj
