@@ -11,7 +11,8 @@ from openride.viewer.hud import Hud
 from openride.viewer.model_loader import ModelLoader
 from openride.viewer.models import DEFAULT_MODELS
 
-from typing import Iterable, List, Tuple, Union
+from typing import Iterable, List, Optional, Tuple, Union
+from vtk.util.numpy_support import vtk_to_numpy
 
 import numpy as np
 import vtk
@@ -23,12 +24,16 @@ class Viewer:
         resolution: Tuple[int, int] = (1600, 900),
         background: Tuple[float, float, float] = (0.05, 0.05, 0.1),
         mouse_camera_interactions: bool = True,
+        render_offscreen: bool = False,
     ):
 
         self.renderer = vtk.vtkRenderer()
         self.renderWindow = vtk.vtkRenderWindow()
         self.renderWindow.AddRenderer(self.renderer)
 
+        if render_offscreen:
+            self.renderWindow.SetOffScreenRendering(1)
+
         self.set_resolution(resolution)
         self.set_background(background)
 
@@ -44,6 +49,7 @@ class Viewer:
         self._text_actor_index = 0
 
     def set_resolution(self, resolution: Tuple[int, int]):
+        self._resolution = resolution
         self.renderWindow.SetSize(resolution[0], resolution[1])
 
     def set_background(self, color=Tuple[float, float, float]):
@@ -52,10 +58,12 @@ class Viewer:
     def set_callback(self, callback: callable):
         self.callbacks.append(callback)
 
-    def update(self):
+    def update(self, return_image: bool = False) -> Optional[np.ndarray]:
         [callback() for callback in self.callbacks]
         self.renderWindow.Render()
         self.__clear_actors()
+        if return_image:
+            return get_last_rendered_image(self)
 
     def render_actor(self, actor: vtk.vtkActor, persist: bool = False):
         self.renderer.AddActor(actor)
@@ -305,3 +313,23 @@ class Viewer:
     def close(self):
         del self.renderWindow
         self.interactor._interactor.InvokeEvent("ExitEvent")
+
+
+def get_last_rendered_image(viewer: Viewer) -> np.ndarray:
+    win_to_img = vtk.vtkWindowToImageFilter()
+    win_to_img.SetShouldRerender(0)
+    win_to_img.SetInput(viewer.renderWindow)
+    win_to_img.Update()
+    vtk_image = win_to_img.GetOutput()
+
+    flip = vtk.vtkImageFlip()
+    flip.SetInputData(vtk_image)
+    flip.SetFilteredAxis(1)
+    flip.FlipAboutOriginOn()
+    flip.Update()
+    vtk_image = flip.GetOutput()
+
+    width, height, _ = vtk_image.GetDimensions()
+    vtk_array = vtk_image.GetPointData().GetScalars()
+    components = vtk_array.GetNumberOfComponents()
+    return vtk_to_numpy(vtk_array).reshape(height, width, components)
